AXDataAxisDescriptor

Trait AXDataAxisDescriptor 

pub unsafe trait AXDataAxisDescriptor: NSCopying {
    // Provided methods
    unsafe fn title(&self) -> Retained<NSString>
       where Self: Sized + Message { ... }
    unsafe fn setTitle(&self, title: &NSString)
       where Self: Sized + Message { ... }
    unsafe fn attributedTitle(&self) -> Retained<NSAttributedString>
       where Self: Sized + Message { ... }
    unsafe fn setAttributedTitle(&self, attributed_title: &NSAttributedString)
       where Self: Sized + Message { ... }
}
Available on crate feature AXAudiograph only.
Describes a data axis for the chart (e.g. X, Y, etc.) Each AXChart requires at least two AXDataAxis objects to describe, at minimum, and X and a Y axis.

See also Apple’s documentation

Provided Methods

unsafe fn title(&self) -> Retained<NSString>
where Self: Sized + Message,

The name or title of this axis.

unsafe fn setTitle(&self, title: &NSString)
where Self: Sized + Message,

Setter for title.

This is copied when set.

unsafe fn attributedTitle(&self) -> Retained<NSAttributedString>
where Self: Sized + Message,

An attributed version of the title of this axis. When set, this will be used instead of title.

unsafe fn setAttributedTitle(&self, attributed_title: &NSAttributedString)
where Self: Sized + Message,

Setter for attributedTitle.

This is copied when set.